@@ -86,6 +86,7 @@ macro_rules! and_then {
 /// assert_eq!(em!(c.get Enum::C{y, x}), Some((5, 4)));
 /// assert_eq!(em!(c.get Enum::C{x, ..}), Some((4,)));
 /// assert_eq!(em!(d.get Enum::D|), Some(())); // Unit variant must follow by '|'
+/// assert_eq!(em!(Enum::D => get Enum::D|), Some(()));
 ///
 /// // Variants Detect
 ///
@@ -105,6 +106,8 @@ macro_rules! and_then {
 /// assert_eq!(em!(c.is Enum::B[]), false);
 ///
 /// assert_eq!(em!(d.is Enum::D|), true); // Unit variant must follow by '|'
+/// // or
+/// assert_eq!(em!(Enum::D => is Enum::D|), true); // Unit variant must follow by '|'
 ///
 /// // Map
 ///
@@ -154,6 +157,9 @@ macro_rules! em {
     ( $i:ident.$m:ident $p:path| $(> $($a:expr),+)? ) => {
         $crate::$m!($i, $p $(, $($a),+)?)
     };
+    ( $i:expr => $m:ident $p:path| $(> $($a:expr),+)? ) => {
+        $crate::$m!($i, $p $(, $($a),+)?)
+    };
 }
 
 #[cfg(test)]
@@ -183,6 +189,7 @@ mod tests {
         assert_eq!(em!(c.get Enum::C{x, y}), Some((4, 5)));
         assert_eq!(em!(c.get Enum::C{x, ..}), Some((4,)));
         assert_eq!(em!(d.get Enum::D|), Some(()));
+        assert_eq!(em!(Enum::D => get Enum::D|), Some(()));
     }
 
     #[test]
@@ -191,6 +198,7 @@ mod tests {
         assert_eq!(em!(a.get Enum::C{x, y}), None);
         assert_eq!(em!(b.get Enum::A), None);
         assert_eq!(em!(c.get Enum::B[i, j]), None);
+        assert_eq!(em!(Enum::A(1) => get Enum::D|), None);
     }
 
     #[test]
